#include "aled.h"  // Indoor Corgi アドレサブルRGB LED制御ライブラリを使用

//----------------------------------------------------------------
// パラメーター設定
//  ここにあるパラメーターを変更してイルミネーションをカスタマイズする

uint16_t ledCount = 34;  // LED数(制御可能な数) 複数のデバイスをつなぐ場合は最大値
float hue = 0.0;        // 基準の色 色相, 0.0 ~ 360.0
float sat = 100.0;        // 基準の色 彩度, 0.0 ~ 100.0
float val = 100.0;         // 基準色 明るさ, 0.0 ~ 100.0
float gradHue = 360.0;    // グラデーション量 色相, 推奨値 0.0 ~ 360.0
float gradSat = 0.0;   // グラデーション量 彩度, 推奨値 -100.0 ~ 100.0
float gradVal = 0.0;  // グラデーション量 明るさ, 推奨値 -100.0 ~ 100.0
float moveSpeed = 1.0;  // 移動(回転)スピード, 推奨値 -10.0 ~ 10.0
float colorChangeHue = 0.0;  // 時間とともに基準の色の色相を変化させる量, 推奨値 0.0 - 5.0
float valMax = 100.0;  // 明るさの最大値, 眩しすぎる場合に下げる, 推奨値 20.0 ~ 100.0
float timeChange = 1.0;  // 消灯と点灯の切り替え時間(秒), 0.0だと常にオン
float timeON = 1.0;      // 点灯のまま保持する時間(秒)
float timeOFF = 0.1;     // 消灯のまま保持する時間(秒)

//----------------------------------------------------------------

// アドレサブルRGB制御用のALEDクラスを使う
ALED aled(CH1 | CH2 | CH3 | CH4 | CH5, ledCount);
uint16_t animationChange;
uint16_t animationON;
uint16_t animationOFF;
float valChange = 0.0f;

void setup() {
  // 使うピンを出力に設定
  pinMode(14, OUTPUT);  // チャネル1 Pin14, PC0
  pinMode(15, OUTPUT);  // チャネル2 Pin15, PC1
  pinMode(16, OUTPUT);  // チャネル3 Pin16, PC2
  pinMode(17, OUTPUT);  // チャネル4 Pin17, PC3
  pinMode(18, OUTPUT);  // チャネル5 Pin18, PC4
  pinMode(8, OUTPUT);   // LED

  aled.pattern = ALED::patGrad;  // グラデーション模様を選択
  aled.color.hue = hue;
  aled.color.sat = sat;
  aled.color.val = val;
  aled.colorPattern.hue = gradHue;
  aled.colorPattern.sat = gradSat;
  aled.colorPattern.val = gradVal;
  aled.val = valMax;
  aled.posChange = moveSpeed;
  aled.colorChange.hue = colorChangeHue;

  if (timeChange > 0.0f) {
    valChange = valMax / timeChange / 30.0f;
    aled.val = 0.0f;
  }
  animationChange = uint16_t(timeChange * 30.0f);
  animationON = uint16_t(timeON * 30.0f);
  animationOFF = uint16_t(timeOFF * 30.0f);
}

void loop() {
  // timeChangeが0以上の場合は点滅
  if (timeChange > 0.0f) {
    aled.valChange = 0.0f;
    aled.animation(animationOFF);

    aled.valChange = valChange;
    aled.animation(animationChange);

    aled.valChange = 0.0f;
    aled.animation(animationON);

    aled.valChange = -valChange;
    aled.animation(animationChange);
  }
  // timeChangeが0の場合は点滅しない
  else {
    aled.animation(1000);
  }
}
